@@ -1,3 +1,6 @@
+from setux.core.package import CommonPackager
+
+
 def run(target, arg):
     target(arg)
 
@@ -68,6 +71,16 @@ def mappings(target, arg):
         for name, pkg in sorted(packages.items()):
             print(f'{name:>{width}} {pkg}')
 
+    for manager in target.managers:
+        if issubclass(manager, CommonPackager) and manager.is_supported(target.distro):
+            packages = manager.pkgmap
+            if packages:
+                print(f'{manager.manager} :')
+                w = len(max(packages.keys(), key=len))+4
+                width = max(width, w)
+                for name, pkg in sorted(packages.items()):
+                    print(f'{name:>{width}} {pkg}')
+
     services = target.svcmap
     if services:
         print('\nservices :')
